@@ -4,7 +4,7 @@
  *
  * An implementation of Regularized SVD.
  *
- * This file is part of MLPACK 1.0.9.
+ * This file is part of MLPACK 1.0.10.
  *
  * MLPACK is free software: you can redistribute it and/or modify it under the
  * terms of the GNU Lesser General Public License as published by the Free
@@ -30,8 +30,8 @@ template<template<typename> class OptimizerType>
 RegularizedSVD<OptimizerType>::RegularizedSVD(const arma::mat& data,
                                               arma::mat& u,
                                               arma::mat& v,
-                                              const long rank,
-                                              const long iterations,
+                                              const size_t rank,
+                                              const size_t iterations,
                                               const double alpha,
                                               const double lambda) :
     data(data),
@@ -45,12 +45,12 @@ RegularizedSVD<OptimizerType>::RegularizedSVD(const arma::mat& data,
   arma::mat parameters = rSVDFunc.GetInitialPoint();
 
   // Train the model.
-
+  Timer::Start("regularized_svd_optimization");
   const double out = optimizer.Optimize(parameters);
-
+  Timer::Stop("regularized_svd_optimization");
   
-  const long numUsers = max(data.row(0)) + 1;
-  const long numItems = max(data.row(1)) + 1;
+  const size_t numUsers = max(data.row(0)) + 1;
+  const size_t numItems = max(data.row(1)) + 1;
   
   u = parameters.submat(0, 0, rank - 1, numUsers - 1);
   v = parameters.submat(0, numUsers, rank - 1, numUsers + numItems - 1);
